Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/wolfpld/tracy.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBartosz Taudul <wolf.pld@gmail.com>2017-11-16 01:03:29 +0300
committerBartosz Taudul <wolf.pld@gmail.com>2017-11-16 01:04:07 +0300
commit0d7ba57fa44b394f5ccef791272eceb315a7d248 (patch)
tree3dcc30efde56db55d26f09b9d67f0dce2d25645f /server/tracy_flat_hash_map.hpp
parent3bc483bd9e37d8effef9b3abd56c05e9aeff05e2 (diff)
Move flat_hash_map to tracy namespace.
Diffstat (limited to 'server/tracy_flat_hash_map.hpp')
-rw-r--r--server/tracy_flat_hash_map.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/server/tracy_flat_hash_map.hpp b/server/tracy_flat_hash_map.hpp
index b6f991c0..d65b5fb6 100644
--- a/server/tracy_flat_hash_map.hpp
+++ b/server/tracy_flat_hash_map.hpp
@@ -21,7 +21,7 @@
#define SKA_NOINLINE(...) __VA_ARGS__ __attribute__((noinline))
#endif
-namespace ska
+namespace tracy
{
struct prime_number_hash_policy;
struct power_of_two_hash_policy;
@@ -1435,7 +1435,7 @@ public:
template<typename T>
struct power_of_two_std_hash : std::hash<T>
{
- typedef ska::power_of_two_hash_policy hash_policy;
+ typedef tracy::power_of_two_hash_policy hash_policy;
};
-} // end namespace ska
+} // end namespace tracy